<?php
/*-------------------------------------------------------+
| PHPFusion Content Management System
| Copyright (C) PHP Fusion Inc
| https://phpfusion.com/
+--------------------------------------------------------+
| Filename: infusion_db.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
require_once __DIR__.'/../../maincore.php';
require_once FUSION_ADMIN_HEADER;
pageAccess('NTFP');

$locale = fusion_get_locale('', NOTIFIER_LOCALE);

add_breadcrumb(["link" => NOTIFIER_PATH.'admin.php'.fusion_get_aidlink(), "title" => $locale['NTFP_003']]);

add_to_title($locale['NTFP_003']);
require_once NOTIFIER_PATH."templates/notifier.tpl.php";

$allowed_section = ['ntfuser', 'ntflink', 'ntfnotify', 'settings'];

$section = get('section', FILTER_DEFAULT);
$section = isset($section) && in_array($section, $allowed_section) ? $section : $allowed_section[0];

$action = check_get('action') ? get('action') : '';

$edit = ($section == 'add') && check_get('n_id');

$tab = [
    'title' => [
        0 => $locale['NTFP_013'],
        1 => $locale['NTFP_014'],
        2 => $locale['NTFP_015'],
        3 => $locale['NTFP_024']
    ],
    'id'    => $allowed_section,
    'icon'  => [
        0 => "fa fa-user",
        1 => "fa fa-link",
        2 => "fa fa-pencil-alt",
        3 => "fa fa-cogs",
    ]
];
opentable($locale['NTFP_003']);
echo opentab($tab, $section, 'personal_admin', TRUE, '', 'section', ['rowstart', 'sortby', 'n_id', 'action']);
switch ($section) {
    case "ntflink":
        ntflinkList();
        break;
    case "ntfnotify":
        ntfdescList();
        break;
    case "settings":
        ntfSettings();
        break;
    default:
        ntfuserList();
        break;
}
echo closetab();
closetable();

function ntfsql(array $filters = []) {
	return "SELECT n.*, nu.*, u.user_name as name, u.user_id as uid, u.user_status as ustatus
	    FROM ".DB_NOTIFIER." AS n
	    LEFT JOIN ".DB_USERS." AS nu ON nu.user_id = n.n_whouser
	    LEFT JOIN ".DB_USERS." AS u ON u.user_id = n.n_userid
        ".(!empty($filters['condition']) ? 'WHERE '.$filters['condition'] : '')."
        ".(multilang_table("NTFP") ? (!empty($filters['condition']) ? ' AND ' : 'WHERE ').in_group('n.n_language', LANGUAGE) : '')."
        ".(!empty($filters['order']) ? 'ORDER BY '.$filters['order'] : '')."
        ".(!empty($filters['limit']) ? "LIMIT ".$filters['limit'] : '')."
	";
}

function ntfSettings() {
    $ntfsettings = get_settings("notifier");
    $locale = fusion_get_locale();
    if (check_post('savesettings')) {
        $savest = [
            'ntf_user' => sanitizer('ntf_user', '', 'ntf_user'),
            'ntf_page' => sanitizer('ntf_page', 15, 'ntf_page')
        ];
        if (fusion_safe()) {
            foreach ($savest as $settings_name => $settings_value) {
                $inputSettings = [
                    'settings_name'  => $settings_name,
                    'settings_value' => $settings_value,
                    'settings_inf'   => 'notifier'
                ];
                dbquery_insert(DB_SETTINGS_INF, $inputSettings, 'update', ['primary_key' => 'settings_name']);
            }
            addnotice('success', $locale['NTFP_058']);
            redirect(clean_request('', ['section', 'aid'], TRUE));
        }
    }

    $result = dbquery("SELECT * FROM ".DB_USERS." WHERE user_level <= '".USER_LEVEL_ADMIN."'");
    if (dbrows($result)) {
        while ($data = dbarray($result)) {
        	$ntfuser[$data['user_id']] = $data['user_name'];
        }
    }
    echo openform('notifierFrm', 'post', FUSION_REQUEST);
    echo form_select('ntf_user', $locale['NTFP_059'], $ntfsettings['ntf_user'], [
        'inline'     => TRUE,
        'options'    => $ntfuser,
        'allowclear' => TRUE
    ]);
    echo form_text('ntf_page', $locale['NTFP_060'], $ntfsettings['ntf_page'], [
        'inline'      => TRUE,
        'required'    => TRUE,
        'number'      => TRUE,
        'max_length'  => 4,
        'type'        => 'number',
        'inner_width' => '150px'
    ]);
    echo form_button('savesettings', $locale['save'], $locale['save'], ['class' => 'btn-primary']);
    echo closeform();
}

function ntfuserList() {
    if (check_get('action') && (get('action') == 'delete') && get('n_id', FILTER_VALIDATE_INT)) {
        ntfdelete(get('n_id'), "ntfuser");
    }
    $locale = fusion_get_locale();
    $ntfsettings = get_settings("notifier");
    $page = $ntfsettings['ntf_page'];
    $not_rows = dbcount("(n_id)", DB_NOTIFIER, "n_whouser != '0'".(multilang_table("NTFP") ? ' AND '.in_group('n_language', LANGUAGE) : ''));
    $rowstart = get_rowstart("rowstart", $not_rows);
    $result = dbquery(ntfsql(['condition' => "n_whouser != '0'", 'order' => "n_date DESC", 'limit' => "$rowstart, $page"]));
    $inf = [];

    $info['count'] =  sprintf($locale['NTFP_056'], $not_rows, $locale['NTFP_013']);
    $info['norows'] = empty($not_rows) ? sprintf($locale['NTFP_055'], $locale['NTFP_013']) : '';
    if (dbrows($result)) {
        $info['bady'] = [$locale['NTFP_013'], $locale['NTFP_052'], $locale['NTFP_053'], $locale['NTFP_054']];
        $info['pagenav'] = makepagenav($rowstart, $page, $not_rows, 3, FUSION_REQUEST."&");
        while($data = dbarray($result)) {
            $inf['data'][] = [
                'notifier' => "<a href='".ADMIN."members.php".fusion_get_aidlink()."&ref=view&lookup=".$data['user_id']."'>".$data['user_name']."</a>",
                'descript' => $data['n_descript'],
                'date'     => showdate('longdate', $data['n_date']),
                'u_name'   => profile_link($data['uid'], $data['name'], $data['ustatus']),
                'link'     => clean_request("section=ntfuser&action=delete&n_id=".$data['n_id'], ['section', 'ref', 'action', 'n_id'], FALSE)
            ];
        }
    }
    $info += $inf;
    ntfShowAdmin($info);
}

function ntflinkList() {
    if (check_get('action') && (get('action') == 'delete') && get('n_id', FILTER_VALIDATE_INT)) {
        ntfdelete(get('n_id'), "ntflink");
    }
    $locale = fusion_get_locale();
    $ntfsettings = get_settings("notifier");
    $page = $ntfsettings['ntf_page'];
    $not_rows = dbcount("(n_id)", DB_NOTIFIER, "n_link != ''".(multilang_table("NTFP") ? ' AND '.in_group('n_language', LANGUAGE) : ''));
    $rowstart = get_rowstart("rowstart", $not_rows);
    $result = dbquery(ntfsql(['condition' => "n_link != ''", 'order' => "n_date DESC", 'limit' => "$rowstart, $page"]));
    $inf = [];
    $info['count'] =  sprintf($locale['NTFP_056'], $not_rows, $locale['NTFP_014']);
    $info['norows'] = empty($not_rows) ? sprintf($locale['NTFP_055'], $locale['NTFP_014']) : '';
    if (dbrows($result)) {
        $info['bady'] = [$locale['NTFP_014'], $locale['NTFP_052'], $locale['NTFP_053'], $locale['NTFP_054']];
        $info['pagenav'] = makepagenav($rowstart, $page, $not_rows, 3, FUSION_REQUEST."&");
        while($data = dbarray($result)) {
            $inf['data'][] = [
                'notifier' => $data['n_link'],
                'descript' => $data['n_descript'],
                'date'     => showdate('longdate', $data['n_date']),
                'u_name'   => profile_link($data['uid'], $data['name'], $data['ustatus']),
                'link'     => clean_request("section=ntflink&action=delete&n_id=".$data['n_id'], ['section', 'ref', 'action', 'n_id'], FALSE)
            ];
        }
    }
    $info += $inf;
    ntfShowAdmin($info);
}

function ntfdescList() {
    if (check_get('action') && (get('action') == 'delete') && get('n_id', FILTER_VALIDATE_INT)) {
        ntfdelete(get('n_id'), "ntfnotify");
    }
    $locale = fusion_get_locale();
    $ntfsettings = get_settings("notifier");
    $page = $ntfsettings['ntf_page'];
    $not_rows = dbcount("(n_id)", DB_NOTIFIER, "n_notifier != ''".(multilang_table("NTFP") ? ' AND '.in_group('n_language', LANGUAGE) : ''));
    $rowstart = get_rowstart("rowstart", $not_rows);
    $result = dbquery(ntfsql(['condition' => "n_notifier != ''", 'order' => "n_date DESC", 'limit' => "$rowstart, $page"]));
    $inf = [];

    $info['count'] =  sprintf($locale['NTFP_056'], $not_rows, $locale['NTFP_015']);
    $info['norows'] = empty($not_rows) ? sprintf($locale['NTFP_055'], $locale['NTFP_015']) : '';
    if (dbrows($result)) {
        $info['bady'] = [$locale['NTFP_015'], $locale['NTFP_052'], $locale['NTFP_053'], $locale['NTFP_054']];
        $info['pagenav'] = makepagenav($rowstart, $page, $not_rows, 3, FUSION_REQUEST."&");
        while($data = dbarray($result)) {
            $inf['data'][] = [
                'notifier' => $data['n_notifier'],
                'descript' => $data['n_descript'],
                'date'     => showdate('longdate', $data['n_date']),
                'u_name'   => profile_link($data['uid'], $data['name'], $data['ustatus']),
                'link'     => clean_request("section=ntfnotify&action=delete&n_id=".$data['n_id'], ['section', 'ref', 'action', 'n_id'], FALSE)
            ];
        }
    }
    $info += $inf;
    ntfShowAdmin($info);
}

function ntfdelete($deleteid = '', $sect = '') {
    if (!empty($deleteid)) {
        $locale = fusion_get_locale();
        dbquery("DELETE FROM ".DB_NOTIFIER." WHERE n_id = :nid", [':nid' => (int)$deleteid]);
        addnotice("success", $locale['NTFP_057']);
        redirect(clean_request("section=".$sect, ["", "aid"]));
    }
}
require_once FUSION_FOOTER;
